@@ -15,27 +15,26 @@ log.setLevel(config.log_level)
 def main():
     print("\n" + "-" * 35 + "Shakersynth" + "-" * 35)
     # Audio synthesis setup.
-    api = config.audio_api
-    print(f"Using audio API: {api}")
     server = pyo.Server(
         nchnls=2,
         duplex=0,
         buffersize=config.buffer_size,
-        winhost=api,
         sr=config.sample_rate
     )
     server.setVerbosity(1)
 
     # Map audio outputs from internal numbers (which can be sparse and large)
     # to a friendly, 1-indexed, monotonic series for the user.
+    print("Scanning audio devices...")
     output_devices = pyo.pa_get_devices_infos()[1]
+    default_api = pyo.pa_get_default_host_api()
     friendly_to_internal = {}
 
     print("Found these audio outputs:")
     device_details = enumerate(output_devices.items())
     for friendly_index, (internal_index, properties) in device_details:
         # Only list devices that are available using the default audio API.
-        if properties["host api index"] == pyo.pa_get_default_host_api():
+        if properties["host api index"] == default_api:
             friendly_index += 1
             friendly_to_internal[friendly_index] = internal_index
             print(f"  {friendly_index}: {properties['name']}")
@@ -63,7 +62,7 @@ def main():
 
     # A little state machine to keep track of our aircraft and telemetry.
     while True:
-        telemetry = receiver.get_telemetry()
+        telemetry = receiver.receive()
         running = aircraft.is_running
 
         if telemetry and not running:
