@@ -7,38 +7,71 @@ log.setLevel(config.log_level)
 
 
 class RotorSynth():
+    """Effect synthesizer for helicopter rotor vibrations.
+
+    This a stereo (2 channel) effect.
+    """
     def __init__(self):
+        """Create a new RotorSynth."""
         self.is_running = False
+
+        # Create two volume faders which we'll use to control
+        # the volume of the effect.
         self.fader0 = pyo.Fader()
         self.fader1 = pyo.Fader()
 
+        # These Lorenz attractors create randomness, which we will use to
+        # modulate the signal a little. It adds character and makes the
+        # effect feel less repetitive.
         self.lorenz0 = pyo.Lorenz(pitch=0.1)
         self.lorenz0_scaled = pyo.Scale(self.lorenz0, outmin=0.3, outmax=0.9)
-        self.lorenz1 = pyo.Lorenz(pitch=0.11)
+        self.lorenz1 = pyo.Lorenz(pitch=0.11)  # Slightly different for stereo.
         self.lorenz1_scaled = pyo.Scale(self.lorenz1, outmin=0.3, outmax=0.9)
 
-        self.osc0 = pyo.LFO(freq=0.0001, sharp=self.lorenz0_scaled, mul=self.fader0)
-        self.osc1 = pyo.LFO(freq=0.0001, sharp=self.lorenz1_scaled, mul=self.fader1)
+        # These are the actual signal sources. Volume is controlled by the
+        # fader objects and the "sharpness" of the wave is modulated by the
+        # Lorenz attractors.
+        self.osc0 = pyo.LFO(
+            freq=0.0001,
+            sharp=self.lorenz0_scaled,
+            mul=self.fader0)
+        self.osc1 = pyo.LFO(
+            freq=0.0001,
+            sharp=self.lorenz1_scaled,
+            mul=self.fader1)
 
+        # Then we'll filter the signals so that only low frequencies are
+        # sent to the shakers.
         self.filter0 = pyo.Biquad(self.osc0, freq=200)
         self.filter1 = pyo.Biquad(self.osc1, freq=200)
 
+        # Finally, hook the output of the filters up to the sound card's left
+        # and right channels.
         self.filter0.out(0)
         self.filter1.out(1)
 
-    def update(self, telemetry: dict):
-        """Update synth parameters based on telemetry."""
+    def update(self, telemetry: dict) -> None:
+        """Update synth parameters based on `telemetry`.
+
+        Each time `update` is called with a `telemetry` payload, the
+        `RotorSynth` will adjust its synthesis parameters to match.
+
+        `telemetry` must contain the key `rotor_rpm_percent` to have
+        any effect.
+
+        Supports the Mi-8 and UH-1H modules.
+        """
         rpm = self._calculate_rotor_rpm(telemetry)
 
+        # Protect against divide-by-zero errors.
         if rpm == 0:
             rpm = 0.00000001
 
-        module = telemetry["module"]
-
         # Revolutions per second is more useful than RPM.
         revolutions_per_second = rpm / 60.0
 
-        if(module == "mi-8"):
+        module = telemetry["module"]
+        if(module == "mi-8mt" or module == "mi-24p"):
             blade_count = 5
         elif(module == "uh-1h"):
             blade_count = 2
@@ -59,7 +92,8 @@ class RotorSynth():
         self.lorenz1_scaled.setOutMin(min(0.3, blades_per_second))
         self.lorenz1_scaled.setOutMax(min(0.9, blades_per_second))
 
-    def start(self):
+    def start(self) -> None:
+        """Start the `RotorSynth`, activating audio output."""
         if self.is_running:
             return
         log.debug("Started.")
@@ -67,7 +101,8 @@ class RotorSynth():
         self.fader1.play()
         self.is_running = True
 
-    def stop(self):
+    def stop(self) -> None:
+        """Stop the `RotorSynth`, deactivating audio output."""
         if not self.is_running:
             return
         log.debug("Stopped.")
@@ -80,10 +115,13 @@ class RotorSynth():
         module = telemetry["module"]
         rpm_percent = telemetry["rotor_rpm_percent"]
 
-        if(module == "mi-8"):
+        if(module == "mi-8mt"):
             # 95 gauge RPM == 192 real rotor RPM. [1, 2]
             # But 200 gives better results in the sim.
             return float(rpm_percent * (200 / 95))
+        elif(module == "mi-24p"):
+            # 280 gives good sync on the Hind, but that seems way off??
+            return float(rpm_percent * (280 / 95))
         elif(module == "uh-1h"):
             # 90 gauge RPM == 324 real rotor RPM. [3]
             return float(rpm_percent * (324 / 90))
